==> derfinderData_2.2.1.tar.gz: derfinderData/README.md <==
<a href="https://bioconductor.org/packages/stats/bioc/derfinderData/"><img border="0" src="http://bioconductor.org/shields/downloads/release/derfinderData.svg" title="Percentile (top 5/20/50% or 'available') of downloads over last 6 full months. Comparison is done across all package categories (software, annotation, experiment)."></a> <a href="https://support.bioconductor.org/t/derfinderData/"><img border="0" src="http://bioconductor.org/shields/posts/derfinderData.svg" title="Support site activity, last 6 months: tagged questions/avg. answers per question/avg. comments per question/accepted answers, or 0 if no tagged posts."></a> <a href="http://bioconductor.org/packages/release/data/experiment/html/derfinderData.html#svn_source"><img border="0" src="http://bioconductor.org/shields/lastcommit/release/data-experiment/derfinderData.svg" title="average Subversion commits (to the devel branch) per month for the last 6 months"></a>

Status: <a href="http://bioconductor.org/packages/release/data/experiment/html/derfinderData.html#archives"><img border="0" src="http://bioconductor.org/images/shields/availability/all.svg" title="Whether the package is available on all platforms; click for details."></a>
Bioc-release <a href="http://bioconductor.org/checkResults/release/bioc-LATEST/derfinderData/"><img border="0" src="http://bioconductor.org/shields/build/release/data-experiment/derfinderData.svg" title="build results; click for full report"></a>,
Bioc-devel <a href="http://bioconductor.org/checkResults/devel/bioc-LATEST/derfinderData/"><img border="0" src="http://bioconductor.org/shields/build/devel/data-experiment/derfinderData.svg" title="build results; click for full report"></a>.

derfinderData
=============

Data package for [derfinder](http://bioconductor.org/packages/derfinder) and [derfinderPlot](http://bioconductor.org/packages/derfinderPlot) examples.

# Installation instructions

Get R 3.5.x or newer from [CRAN](http://cran.r-project.org/).

```R
## If needed
install.packages('BiocManager')
BiocManager::install('derfinderData')
```

# Citation

Use [derfinder's citation](https://github.com/lcolladotor/derfinder#citation) information.

==> derfinderData_2.4.0.tar.gz: derfinderData/README.md <==
<a href="https://bioconductor.org/packages/stats/bioc/derfinderData/"><img border="0" src="http://bioconductor.org/shields/downloads/release/derfinderData.svg" title="Percentile (top 5/20/50% or 'available') of downloads over last 6 full months. Comparison is done across all package categories (software, annotation, experiment)."></a> <a href="https://support.bioconductor.org/t/derfinderData/"><img border="0" src="http://bioconductor.org/shields/posts/derfinderData.svg" title="Support site activity, last 6 months: tagged questions/avg. answers per question/avg. comments per question/accepted answers, or 0 if no tagged posts."></a> <a href="http://bioconductor.org/packages/release/data/experiment/html/derfinderData.html#svn_source"><img border="0" src="http://bioconductor.org/shields/lastcommit/release/data-experiment/derfinderData.svg" title="average Subversion commits (to the devel branch) per month for the last 6 months"></a>

Status: <a href="http://bioconductor.org/packages/release/data/experiment/html/derfinderData.html#archives"><img border="0" src="http://bioconductor.org/images/shields/availability/all.svg" title="Whether the package is available on all platforms; click for details."></a>
Bioc-release <a href="http://bioconductor.org/checkResults/release/bioc-LATEST/derfinderData/"><img border="0" src="http://bioconductor.org/shields/build/release/data-experiment/derfinderData.svg" title="build results; click for full report"></a>,
Bioc-devel <a href="http://bioconductor.org/checkResults/devel/bioc-LATEST/derfinderData/"><img border="0" src="http://bioconductor.org/shields/build/devel/data-experiment/derfinderData.svg" title="build results; click for full report"></a>.

derfinderData
=============

Data package for [derfinder](http://bioconductor.org/packages/derfinder) and [derfinderPlot](http://bioconductor.org/packages/derfinderPlot) examples.

# Installation instructions

Get R 3.5.x or newer from [CRAN](http://cran.r-project.org/).

```R
if (!requireNamespace("BiocManager", quietly = TRUE))
    install.packages("BiocManager")

BiocManager::install("derfinderData")
```

# Citation

Use [derfinder's citation](https://github.com/lcolladotor/derfinder#citation) information.
